#!/bin/bash

# set explanations:
# -x will cause the commands to be printed out, so we can track what's being
#    run more easily.
# -e will cause the script to exit immediately if any command within it exits non 0
# -o pipefail : this will cause the script to exit with the last exit code run.
#               In tandem with -e, it will return the exit code of the first
#               failing command.
set -eox pipefail

# Enable Developer Tools
DevToolsSecurity -enable

# Disable screensaver
su -l "${USERNAME}" -c 'defaults -currentHost write com.apple.screensaver idleTime 0'

# Disable spotlight
launchctl unload -w /System/Library/LaunchDaemons/com.apple.metadata.mds.plist

# Disable lots of animations
defaults write NSGlobalDomain NSAutomaticWindowAnimationsEnabled -bool false
defaults write NSGlobalDomain NSWindowResizeTime -float 0.001
defaults write com.apple.dock expose-animation-duration -int 0
defaults write com.apple.dock launchanim -bool false

# Never try to sleep harddrives
systemsetup -setsleep Never
systemsetup -setharddisksleep Never
systemsetup -setcomputersleep Never
systemsetup -setdisplaysleep Never

# Set the computer name, for example setting the name to
# "MyComputer" would make the system reachable at MyComputer.local
# on the local network
scutil --set LocalHostName "${MACHINE_NAME}"
scutil --set HostName "${MACHINE_NAME}"
scutil --set ComputerName "${MACHINE_NAME}.local"
